@@ -24,7 +24,8 @@ ProcessModelsMetaData['LF'] = {}
 ProcessModelsMetaData['LF']['Name'] = 'Landfill'
 ProcessModelsMetaData['LF']['Process_Type'] = 'Treatment'
 ProcessModelsMetaData['LF']['File'] = 'LF.py'
-ProcessModelsMetaData['LF']['InputType'] = ['RWC', 'MRDO', 'Other_Residual', 'Bottom_Ash', 'Fly_Ash']
+ProcessModelsMetaData['LF']['InputType'] = ['RWC', 'MRDO', 'Other_Residual', 'Bottom_Ash',
+                                            'Fly_Ash', 'Unreacted_Ash']
 
 ProcessModelsMetaData['SS_MRF'] = {}
 ProcessModelsMetaData['SS_MRF']['Name'] = 'Single Stream Material Recovery Facility'
@@ -57,4 +58,17 @@ ProcessModelsMetaData['HC'] = {}
 ProcessModelsMetaData['HC']['Process_Type'] = 'Treatment'
 ProcessModelsMetaData['HC']['Name'] = 'Home Composting'
 ProcessModelsMetaData['HC']['File'] = 'HC.py'
-ProcessModelsMetaData['HC']['InputType'] = ['SSO_HC']
\ No newline at end of file
+ProcessModelsMetaData['HC']['InputType'] = ['SSO_HC']
+
+ProcessModelsMetaData['GC'] = {}
+ProcessModelsMetaData['GC']['Process_Type'] = 'RDF'
+ProcessModelsMetaData['GC']['Name'] = 'Gasification Syngas Combustion'
+ProcessModelsMetaData['GC']['File'] = 'GC.py'
+ProcessModelsMetaData['GC']['InputType'] = ['RDF']
+
+ProcessModelsMetaData['RDF'] = {}
+ProcessModelsMetaData['RDF']['Process_Type'] = 'Treatment'
+ProcessModelsMetaData['RDF']['Name'] = 'Refuse-Derived Fuel'
+ProcessModelsMetaData['RDF']['File'] = 'RDF.py'
+ProcessModelsMetaData['RDF']['InputType'] = ['RWC', 'MRDO']
+
